@@ -21,22 +21,16 @@
 # limitations under the License.
 
 from __future__ import print_function
-from opsramp.base import ApiWrapper
+from opsramp.api import ORapi
 
 
-class Sites(ApiWrapper):
+class Sites(ORapi):
     def __init__(self, parent):
         super(Sites, self).__init__(parent.api, 'sites')
 
     def get(self, suffix='/minimal'):
         return self.api.get(suffix)
 
-    def search(self, pattern=''):
-        suffix = 'search'
-        if pattern:
-            suffix += '?' + pattern
-        return self.api.get(suffix)
-
     def create(self, definition):
         return self.api.post('', json=definition)
 
