@@ -2,7 +2,7 @@
 #
 # Exercise the opsramp module as an illustration of how to use it.
 #
-# (c) Copyright 2019 Hewlett Packard Enterprise Development LP
+# (c) Copyright 2019-2020 Hewlett Packard Enterprise Development LP
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -46,6 +46,10 @@ def main():
     group.redact_response(resp)
     print(yaml.dump(resp, indent=2))
 
+    resp_config = group.get_kubernetes_configuration(uniqueId)
+    resp_list = list(yaml.load_all(resp_config, Loader=yaml.SafeLoader))
+    print(yaml.dump(resp_list, indent=2))
+
 
 if __name__ == "__main__":
     main()
